@@ -1,6 +1,7 @@
 #ifndef LIBFILEZILLA_LOCAL_FILESYS_HEADER
 #define LIBFILEZILLA_LOCAL_FILESYS_HEADER
 
+#include "fsresult.hpp"
 #include "libfilezilla.hpp"
 #include "time.hpp"
 
@@ -15,36 +16,6 @@
  */
 namespace fz {
 
-/**
- * \brief Small class to return filesystem errors
- */
-class FZ_PUBLIC_SYMBOL result final
-{
-public:
-	enum error {
-		ok,
-
-		/// Permission denied
-		noperm,
-
-		/// Requested file does not exist or is not a file
-		nofile,
-
-		/// Requested dir does not exist or is not a dir
-		nodir,
-
-		/// Out of disk space
-		nospace,
-
-		/// Some other error
-		other
-	};
-
-	explicit operator bool() const { return error_ == 0; }
-
-	error error_{};
-};
-
 /**
  * \brief This class can be used to enumerate the contents of local directories and to query
  * the metadata of files.
